==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditTextTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditTextTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditTextTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Number:double");
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
        a.ad("WebGridRowEditTextTemplateContext", function () { return new WebGridRowEditTextTemplateContextDescription(); });
        a.ac("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditTextTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGridRowEditTextTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditTextTemplateContextDescription } from "./WebGridRowEditTextTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditTextTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditTextTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditTextTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditTextTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditTextTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditTextTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditTextTemplateContextDescriptionMetadata.c(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditTextTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditTextTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Number:double");
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditTextTemplateContextDescriptionMetadata.b(a);
        a.ae("WebGridRowEditTextTemplateContext", function () { return new WebGridRowEditTextTemplateContextDescription(); });
        a.ad("WebGridRowEditTextTemplateContext", WebGridRowEditTextTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditTextTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditTextTemplateContextDescriptionMetadata, 'WebGridRowEditTextTemplateContextDescriptionMetadata');
    WebGridRowEditTextTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditTextTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditTextTemplateContextDescriptionMetadata };
